description WIP

## Features
- Fun to play!
- Easy to install
- 100% Test Coverage
- Play rock paper scissors with computer
- Beautiful ASCII art
- Tested using GitHub Actions

![RPS workflow](https://github.com/software-students-fall2022/python-package-exercise-project-3-team-6/actions/workflows/tests.yml/badge.svg)

## Quickstart
Installing Rock Paper Scissors Game is simple with [pipenv](https://pypi.org/project/pipenv/). <br>
```pipenv install RockPaperScissorsFullGame```

Run the package directly from the command line: <br>
```python -m RockPaperScissorsFullGame```

